"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildPdfForLastDocumentCapture = buildPdfForLastDocumentCapture;
exports.captureDocument = captureDocument;
exports.captureOpticalCode = captureOpticalCode;
exports.generateBarcode = generateBarcode;
exports.generateQRCode = generateQRCode;
exports.init = init;
var _reactNative = require("react-native");
const LINKING_ERROR = `The package 'quickcapture' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';
const Quickcapture = _reactNative.NativeModules.Quickcapture ? _reactNative.NativeModules.Quickcapture : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});

/**
 * Initializes the Quickcapture module.
 * @returns {boolean} Returns true to indicate successful initialization.
 */
function init() {
  Quickcapture.initialise();
  return true;
}

/**
 * Captures a document using the device camera.
 * @returns {Promise<string>} A promise that resolves to the path of the captured document image.
 */
function captureDocument() {
  return new Promise((resolve, reject) => {
    Quickcapture.startCapture({
      saveToGallery: true
    }).then(responseString => {
      console.log(responseString);
      resolve(responseString); // Resolve the outer promise with the image path
    }).catch(error => {
      console.error(error);
      reject(error); // Reject the outer promise with the error
    });
  });
}

/**
 * Builds a PDF from the last captured document.
 * @returns {Promise<string>} A promise that resolves to the file path of the generated PDF.
 */
function buildPdfForLastDocumentCapture() {
  return new Promise((resolve, reject) => {
    Quickcapture.buildPdfFileForLastCaptureSet().then(pdfFilePath => {
      console.log(pdfFilePath);
      resolve(pdfFilePath); // Resolve the outer promise with the image path
    }).catch(error => {
      console.error(error);
      reject(error); // Reject the outer promise with the error
    });
  });
}

/**
 * Captures an optical code (QR code or barcode) using the device camera.
 * @returns {Promise<string>} A promise that resolves to the scanned code data.
 */
function captureOpticalCode() {
  return new Promise((resolve, reject) => {
    Quickcapture.startOpticalCodeCapture({}).then(response => {
      console.log(response);
      resolve(response); // Resolve the outer promise with the image path
    }).catch(error => {
      console.error(error);
      reject(error); // Reject the outer promise with the error
    });
  });
}

/**
 * Generates a QR code from provided data.
 * @param {string} data The data to encode in the QR code.
 * @returns {Promise<string>} A promise that resolves to Base64 data of the generated QR code image.
 */
function generateQRCode(data) {
  return new Promise((resolve, reject) => {
    Quickcapture.generateQRCode(data).then(response => {
      console.log(response);
      resolve(response); // Resolve the outer promise with the image path
    }).catch(error => {
      console.error(error);
      reject(error); // Reject the outer promise with the error
    });
  });
}

/**
 * Generates a barcode from provided data.
 * @param {string} data The data to encode in the barcode.
 * @param {boolean} includeText Optional flag to include text below the barcode.
 * @returns {Promise<string>} A promise that resolves to Base64 data of the generated QR code image.
 */
function generateBarcode(data, includeText = false) {
  return new Promise((resolve, reject) => {
    Quickcapture.generateBarcode(data, includeText).then(response => {
      console.log(response);
      resolve(response); // Resolve the outer promise with the image path
    }).catch(error => {
      console.error(error);
      reject(error); // Reject the outer promise with the error
    });
  });
}
//# sourceMappingURL=index.js.map